summaryrefslogtreecommitdiff
path: root/gcc/function.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/function.c')
-rw-r--r--gcc/function.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/gcc/function.c b/gcc/function.c
index d40801c4078..c240788e30a 100644
--- a/gcc/function.c
+++ b/gcc/function.c
@@ -6795,9 +6795,10 @@ expand_function_end (filename, line, end_bindings)
}
/* Warn about unused parms if extra warnings were specified. */
/* Either ``-W -Wunused'' or ``-Wunused-parameter'' enables this
warning. WARN_UNUSED_PARAMETER is negative when set by
- -Wunused. */
+ -Wunused. Note that -Wall implies -Wunused, so ``-Wall -Wextra'' will
+ also give these warnings. */
if (warn_unused_parameter > 0
|| (warn_unused_parameter < 0 && extra_warnings))
{
@@ -6795,9 +6795,10 @@ expand_function_end (filename, line, end_bindings)
}
/* Warn about unused parms if extra warnings were specified. */
- /* Either ``-W -Wunused'' or ``-Wunused-parameter'' enables this
+ /* Either ``-Wextra -Wunused'' or ``-Wunused-parameter'' enables this
warning. WARN_UNUSED_PARAMETER is negative when set by